/* ver.B.b14.01(BLAZE) */


#include "version.h"


VERSION machine_code_version = {
	"MA.code",
	"posix.MacOSX.Interface",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b14.01(BLAZE)",
	2007,2,27,
	0,
	"machine (posix.MacOSX) dependent library ",
};

